pub fn load_shared_config() -> Result<SharedConfig, ConfigError>Expand description
Load the shared configuration from global and project config files.
Errors
Returns an error if config files exist but cannot be read or parsed.
pub fn load_shared_config() -> Result<SharedConfig, ConfigError>Load the shared configuration from global and project config files.
Returns an error if config files exist but cannot be read or parsed.